{
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#Dockstore.cwl",
            "label": "CGP file checksum generator",
            "doc": "![build_status](https://quay.io/repository/wtsicgp/dockstore-cgp-chksum/status)\nA Docker container for producing file md5sum and sha512sum. See the [dockstore-cgp-chksum](https://github.com/cancerit/dockstore-cgp-chksum) website for more information.\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/wtsicgp/dockstore-cgp-chksum:0.4.1"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-A",
                        "position": 5
                    },
                    "doc": "Flag to suppress all curl exit status",
                    "id": "#Dockstore.cwl/cgp-chksum/ignore_all_curl_exits"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "int",
                            "inputBinding": {
                                "prefix": "-E",
                                "separate": true,
                                "shellQuote": true
                            }
                        }
                    ],
                    "doc": "Optional curl exit codes to suppress",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/ignore_curl_exits"
                },
                {
                    "type": "File",
                    "doc": "file to have checksum generated from",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-i",
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/in_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "use as chksum output instead of generating a new one.",
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-j",
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/in_json"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Optional PUT address to send JSON results",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-p",
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/put_address"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "prefix": "-H",
                                "separate": true,
                                "shellQuote": true
                            }
                        }
                    ],
                    "doc": "Optional headers to send with JSON results",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/put_headers"
                }
            ],
            "baseCommand": [
                "/opt/wtsi-cgp/bin/sums2json.sh"
            ],
            "http://purl.org/dc/terms/creator": {
                "@id": "yaobo.xu@sanger.ac.uk",
                "foaf:name": "Yaobo Xu",
                "foaf:mbox": "yx2@sanger.ac.uk"
            },
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.in_file.basename).check_sums.json"
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/chksum_json"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.in_file.basename).server_response.txt"
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/server_response"
                }
            ]
        },
        {
            "class": "Workflow",
            "id": "#main",
            "label": "A CGP workflow to generate checksum and corruption info of a single file",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "A JSON file of file corruption status",
                    "id": "#main/corruption_status"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Optional PUT address to send JSON results of checksums",
                    "id": "#main/put_address"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "Optional headers to send with JSON results.",
                    "id": "#main/put_headers"
                },
                {
                    "type": "File",
                    "doc": "input file",
                    "id": "#main/xam_in"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/in_chksum/chksum_json",
                    "id": "#main/chksum_json"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/in_chksum/server_response",
                    "id": "#main/chksum_put_server_response"
                },
                {
                    "type": "File",
                    "outputSource": "#main/manifest_string_to_file/outfile",
                    "id": "#main/results_manifest"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "valueFrom": "$(true)",
                            "id": "#main/in_chksum/ignore_all_curl_exits"
                        },
                        {
                            "source": "#main/xam_in",
                            "id": "#main/in_chksum/in_file"
                        },
                        {
                            "source": "#main/put_address",
                            "id": "#main/in_chksum/put_address"
                        },
                        {
                            "source": "#main/put_headers",
                            "id": "#main/in_chksum/put_headers"
                        }
                    ],
                    "out": [
                        "#main/in_chksum/chksum_json",
                        "#main/in_chksum/server_response"
                    ],
                    "run": "#Dockstore.cwl",
                    "id": "#main/in_chksum"
                },
                {
                    "in": [
                        {
                            "source": [
                                "#main/results_manifest_string/out_string"
                            ],
                            "id": "#main/manifest_string_to_file/in_string"
                        }
                    ],
                    "out": [
                        "#main/manifest_string_to_file/outfile"
                    ],
                    "run": "#string_to_file.cwl",
                    "id": "#main/manifest_string_to_file"
                },
                {
                    "in": [
                        {
                            "source": "#main/corruption_status",
                            "id": "#main/results_manifest_string/corruption_status"
                        },
                        {
                            "source": [
                                "#main/in_chksum/chksum_json"
                            ],
                            "linkMerge": "merge_flattened",
                            "id": "#main/results_manifest_string/input_chksum_results"
                        },
                        {
                            "source": [
                                "#main/xam_in"
                            ],
                            "linkMerge": "merge_flattened",
                            "id": "#main/results_manifest_string/input_files"
                        }
                    ],
                    "out": [
                        "#main/results_manifest_string/out_string"
                    ],
                    "run": "#results_manifest_for_corrupted_input.cwl",
                    "id": "#main/results_manifest_string"
                }
            ],
            "doc": "A workflow to generate checksums of a file and add info in corruption_status file into a JSON output. See the [workflow-seq-import](https://github.com/cancerit/workflow-seq-import) website for more information.\n",
            "http://schema.org/codeRepository": "https://github.com/cancerit/workflow-seq-import",
            "http://schema.org/license": "https://spdx.org/licenses/AGPL-3.0",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/email": "mailto:yyaobo@gmail.com",
                    "http://schema.org/name": "Yaobo Xu"
                }
            ],
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Yaobo Xu",
                "foaf:mbox": "genservhelp@sanger.ac.uk"
            }
        },
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "loadContents": true
                    },
                    "id": "#results_manifest_for_corrupted_input.cwl/corruption_status"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "loadContents": true
                        }
                    },
                    "id": "#results_manifest_for_corrupted_input.cwl/input_chksum_results"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#results_manifest_for_corrupted_input.cwl/input_files"
                }
            ],
            "outputs": [
                {
                    "type": "string",
                    "id": "#results_manifest_for_corrupted_input.cwl/out_string"
                }
            ],
            "expression": "${\n  function name_chksum_and_corruption_status(files, chksum_out_json_files, c_file) {\n    var metas = [];\n    var corrupt_obj = JSON.parse(c_file.contents);\n    for (var i=0; i<files.length; i++) {\n      var chksum_obj = JSON.parse(chksum_out_json_files[i].contents);\n      var temp_obj = {name: files[i].basename, size: files[i].size, md5: chksum_obj.md5sum, sha2: chksum_obj.sha2sum}\n      if (files[i].basename in corrupt_obj) {\n        if ('compressed' in corrupt_obj[files[i].basename]) {\n          if ( !corrupt_obj[files[i].basename]['compressed'] || !corrupt_obj[files[i].basename]['expected_type'] ) {\n            temp_obj['corrupted'] = true\n          }\n        } else {\n          if ('expected_type' in corrupt_obj[files[i].basename] && !corrupt_obj[files[i].basename]['expected_type']) {\n            temp_obj['corrupted'] = true\n          }\n        }\n      }\n      metas.push(temp_obj);\n    }\n    return metas;\n  }\n\n  var final_meta;\n  final_meta = { input: name_chksum_and_corruption_status(inputs.input_files, inputs.input_chksum_results, inputs.corruption_status) };\n  return {out_string: JSON.stringify(final_meta)} \n}\n",
            "id": "#results_manifest_for_corrupted_input.cwl"
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#string_to_file.cwl/in_string"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "results_manifest.json"
                    },
                    "id": "#string_to_file.cwl/outfile"
                }
            ],
            "baseCommand": [
                "echo"
            ],
            "stdout": "results_manifest.json",
            "id": "#string_to_file.cwl"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://schema.org/docs/schema_org_rdfa.html"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
